#[repr(i32)]pub enum ExecutionStatus {
Unspecified = 0,
Pending = 1,
InProgress = 2,
Succeeded = 3,
Failed = 4,
Cancelled = 5,
}Expand description
Status of a job execution.
Variants
Unspecified = 0
Unknown status.
Pending = 1
The execution is pending.
InProgress = 2
The execution is in progress.
Succeeded = 3
The execution has completed successfully.
Failed = 4
The execution has failed.
Cancelled = 5
The execution was cancelled.
Implementations
Sourceimpl ExecutionStatus
impl ExecutionStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.