#[repr(i32)]pub enum JobOrderBy {
Unspecified = 0,
CreatedAtAsc = 1,
CreatedAtDesc = 2,
TargetExecutionTimeAsc = 3,
TargetExecutionTimeDesc = 4,
}Expand description
Ordering options for listing jobs.
Variants
Unspecified = 0
Default ordering (by creation time descending).
CreatedAtAsc = 1
Order by creation time ascending.
CreatedAtDesc = 2
Order by creation time descending.
TargetExecutionTimeAsc = 3
Order by target execution time ascending.
TargetExecutionTimeDesc = 4
Order by target execution time descending.
Implementations
Sourceimpl JobOrderBy
impl JobOrderBy
Sourceimpl JobOrderBy
impl JobOrderBy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.