#[repr(i32)]pub enum ScheduleOrderBy {
Unspecified = 0,
CreatedAtAsc = 1,
CreatedAtDesc = 2,
}Expand description
Ordering options for listing schedules.
Variants
Unspecified = 0
Unspecified ordering.
CreatedAtAsc = 1
Order by creation time.
CreatedAtDesc = 2
Order by creation time, descending.
Implementations
Sourceimpl ScheduleOrderBy
impl ScheduleOrderBy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.