#[repr(i32)]pub enum ScheduleStatus {
Unspecified = 0,
Active = 1,
Stopped = 2,
}Expand description
The status of a schedule.
Variants
Unspecified = 0
Unknown status.
Active = 1
The schedule is active.
Stopped = 2
The schedule was stopped.
Once a schedule is stopped, it cannot be re-activated.
Implementations
Sourceimpl ScheduleStatus
impl ScheduleStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.