pub struct AddSchedulesRequest {
pub schedules: Vec<Schedule>,
pub if_not_exists: Option<ScheduleFilters>,
pub inherit_labels: Option<bool>,
}Expand description
Request for AddSchedules.
Fields
schedules: Vec<Schedule>The schedules to be added.
if_not_exists: Option<ScheduleFilters>Optional filters to prevent adding schedules.
If any schedules exist that match the filters, no new schedules will be added.
inherit_labels: Option<bool>Whether to inherit labels from the schedules when creating jobs.
By default, labels are inherited.
Implementations
Sourceimpl AddSchedulesRequest
impl AddSchedulesRequest
Sourcepub fn inherit_labels(&self) -> bool
pub fn inherit_labels(&self) -> bool
Returns the value of inherit_labels, or the default value if inherit_labels is unset.