Execution

Struct Execution 

pub struct Execution {
    pub id: String,
    pub executor_id: Option<String>,
    pub status: i32,
    pub created_at: Option<Timestamp>,
    pub started_at: Option<Timestamp>,
    pub succeeded_at: Option<Timestamp>,
    pub failed_at: Option<Timestamp>,
    pub cancelled_at: Option<Timestamp>,
    pub output_json: Option<String>,
    pub failure_reason: Option<String>,
}
A job execution.

Fields

id: String

The unique ID of the execution.

executor_id: Option<String>

The ID of the executor handling the execution.

status: i32

The status of the execution.

created_at: Option<Timestamp>

The timestamp when the execution was created.

started_at: Option<Timestamp>

The timestamp when the execution started.

succeeded_at: Option<Timestamp>

The timestamp when the execution successfully completed.

failed_at: Option<Timestamp>

The timestamp when the execution failed.

cancelled_at: Option<Timestamp>

The timestamp when the execution was cancelled.

output_json: Option<String>

The output or result of the execution.

failure_reason: Option<String>

The error message if the execution failed or was cancelled.

Implementations

Source

impl Execution

pub fn executor_id(&self) -> &str

Returns the value of executor_id, or the default value if executor_id is unset.

pub fn status(&self) -> ExecutionStatus

Returns the enum value of status, or the default if the field is set to an invalid enum value.

pub fn set_status(&mut self, value: ExecutionStatus)

Sets status to the provided enum value.

pub fn output_json(&self) -> &str

Returns the value of output_json, or the default value if output_json is unset.

pub fn failure_reason(&self) -> &str

Returns the value of failure_reason, or the default value if failure_reason is unset.