pub struct Schedule {
pub id: String,
pub schedule: Option<Schedule>,
pub created_at: Option<Timestamp>,
pub status: i32,
pub stopped_at: Option<Timestamp>,
}Expand description
Schedule details.
Fields
id: StringThe unique ID of the schedule.
schedule: Option<Schedule>The schedule definition.
created_at: Option<Timestamp>The timestamp when the schedule was created.
status: i32The status of the schedule.
stopped_at: Option<Timestamp>The timestamp when the schedule was stopped (if any).
Implementations
Sourceimpl Schedule
impl Schedule
Sourcepub fn status(&self) -> ScheduleStatus
pub fn status(&self) -> ScheduleStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ScheduleStatus)
pub fn set_status(&mut self, value: ScheduleStatus)
Sets status to the provided enum value.