Modules
- execution_
service_ server - Generated server implementations.
- executor_
message - Nested message and enum types in
ExecutorMessage. - server_
message - Nested message and enum types in
ServerMessage.
Structs
- Execution
Cancelled - The job execution was cancelled and should be dropped by the executor.
- Execution
Failed - The job execution has failed.
- Execution
Ready - A job execution is ready to be executed by the executor.
- Execution
Succeeded - A job execution has succeeded.
- Executor
Capabilities - Capabilities of the executor and other information that the server needs to know about the executor.
- Executor
Connection Request - Request for
ExecutorConnection. - Executor
Connection Response - Response for
ExecutorConnection. - Executor
Heartbeat - The heartbeat content.
- Executor
JobQueue - A job queue configuration of the executor.
- Executor
Message - A message sent from the executor.
- Executor
Properties - Properties of the executor assigned by the server.
- Server
Message - A message sent from the server.