Generated server implementations.
Structs
- Execution
Service Server - Endpoint on the server for executors to connect to.
Constants
- SERVICE_
NAME - Generated gRPC service name
Traits
- Execution
Service - Generated trait containing gRPC methods that should be implemented for use with ExecutionServiceServer.